@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tasty-hunit
 version: 0.9.2
-id: tasty-hunit-0.9.2-e1d44484dc0859a198a89b637e3d5133
-key: tasty_7kv5FhZVwprLclivJIQXzM
+id: tasty-hunit-0.9.2-53f0b14839b6dd0e329c2a1e0fb5a69f
+key: tasty_0Ic2vyPDHSfJmXlwvAoOuQ
 license: MIT
 maintainer: Roman Cheplyaka <roma@ro-che.info>
 homepage: http://documentup.com/feuerbach/tasty
@@ -20,10 +20,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-hunit-0.9.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-hunit-0.9.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-hunit-0.9.2
-hs-libraries: HStasty-hunit-0.9.2-7kv5FhZVwprLclivJIQXzM
+hs-libraries: HStasty-hunit-0.9.2-0Ic2vyPDHSfJmXlwvAoOuQ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
+    tasty-0.11.0.3-0d04c7a0c25a1cdf39b68aca17d97b9d
 haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
 haddock-html: /usr/share/doc/haskell-tasty-hunit/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
